@@ -3,7 +3,6 @@ import socket
 import requests as req
 from .env import Env
 from .auth.keycloak import Keycloak
-from requests.exceptions import ConnectionError
 
 
 def load_configs(app_role):
@@ -33,13 +32,9 @@ def load_configs(app_role):
         print(f"loading role: {role}")
         role_uri = f"{configs_protocol}://{configs_host}/api/v1/roles/{role}/configs"
 
-        try:
-            res = req.get(role_uri, headers={
-                "Authorization": f"Bearer {token}",
-            })
-        except ConnectionError:
-            print(f"cannot connect to configs service at [{role_uri}]")
-            return
+        res = req.get(role_uri, headers={
+            "Authorization": f"Bearer {token}",
+        })
 
         if not res.ok:
             print("configs service returned an error")
